@@ -1,13 +1,38 @@
-from __future__ import absolute_import, print_function
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 
-import unittest
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
 
+import pytest ; pytest
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
+
+# External imports
 import jinja2
 
-from bokeh.application.handlers import DirectoryHandler
+# Bokeh imports
 from bokeh.core.templates import FILE
 from bokeh.document import Document
-from bokeh.util.testing import with_directory_contents
+from bokeh._testing.util.filesystem import with_directory_contents
+
+# Module under test
+import bokeh.application.handlers.directory as bahd
+
+#-----------------------------------------------------------------------------
+# Setup
+#-----------------------------------------------------------------------------
 
 script_adds_two_roots_template = """
 from bokeh.io import curdoc
@@ -25,10 +50,6 @@ curdoc().add_root(%s())
 curdoc().add_root(%s())
 """
 
-def script_adds_two_roots(some_model_name, another_model_name):
-    return script_adds_two_roots_template % (another_model_name, some_model_name,
-                                             another_model_name, some_model_name)
-
 script_has_lifecycle_handlers = """
 def on_server_loaded(server_context):
     return "on_server_loaded"
@@ -40,12 +61,26 @@ def on_session_destroyed(session_context):
     return "on_session_destroyed"
 """
 
-class TestDirectoryHandler(unittest.TestCase):
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+def script_adds_two_roots(some_model_name, another_model_name):
+    return script_adds_two_roots_template % (another_model_name, some_model_name,
+                                             another_model_name, some_model_name)
+
+class Test_DirectoryHandler(object):
+
+    # Public methods ----------------------------------------------------------
 
     def test_directory_empty_mainpy(self):
         doc = Document()
         def load(filename):
-            handler = DirectoryHandler(filename=filename)
+            handler = bahd.DirectoryHandler(filename=filename)
             handler.modify_document(doc)
             if handler.failed:
                 raise RuntimeError(handler.error)
@@ -59,7 +94,7 @@ class TestDirectoryHandler(unittest.TestCase):
     def test_directory_mainpy_adds_roots(self):
         doc = Document()
         def load(filename):
-            handler = DirectoryHandler(filename=filename)
+            handler = bahd.DirectoryHandler(filename=filename)
             handler.modify_document(doc)
             if handler.failed:
                 raise RuntimeError(handler.error)
@@ -74,7 +109,7 @@ class TestDirectoryHandler(unittest.TestCase):
     def test_directory_has_theme_file(self):
         doc = Document()
         def load(filename):
-            handler = DirectoryHandler(filename=filename)
+            handler = bahd.DirectoryHandler(filename=filename)
             handler.modify_document(doc)
             if handler.failed:
                 raise RuntimeError(handler.error)
@@ -98,24 +133,24 @@ some.foo = 57
             'theme.yaml' : custom_theme
         }, load)
 
-        self.assertEqual(2, len(doc.roots))
+        assert len(doc.roots) == 2
         some_model = next(m for m in doc.roots if m.__class__.__name__ == 'SomeModelInTestDirectoryTheme')
         another_model = next(m for m in doc.roots if m.__class__.__name__ == 'AnotherModelInTestDirectoryTheme')
-        self.assertEqual(42, another_model.bar)
-        self.assertEqual(57, some_model.foo)
+        assert another_model.bar == 42
+        assert some_model.foo == 57
         # test that we use the theme if we delete our explicit-set value
         del some_model.foo
-        self.assertEqual(14, some_model.foo)
+        assert some_model.foo == 14
         # test that removing the theme gets us back to the base
         doc.theme = None
-        self.assertEqual(2, some_model.foo)
-        self.assertEqual(1, another_model.bar)
+        assert some_model.foo == 2
+        assert another_model.bar == 1
 
     def test_directory_with_server_lifecycle(self):
         doc = Document()
         result = {}
         def load(filename):
-            handler = DirectoryHandler(filename=filename)
+            handler = bahd.DirectoryHandler(filename=filename)
             result['handler'] = handler
             handler.modify_document(doc)
             if handler.failed:
@@ -140,7 +175,7 @@ some.foo = 57
         doc = Document()
         result = {}
         def load(filename):
-            handler = DirectoryHandler(filename=filename)
+            handler = bahd.DirectoryHandler(filename=filename)
             result['handler'] = handler
             handler.modify_document(doc)
             if handler.failed:
@@ -161,7 +196,7 @@ some.foo = 57
         doc = Document()
         result = {}
         def load(filename):
-            handler = DirectoryHandler(filename=filename)
+            handler = bahd.DirectoryHandler(filename=filename)
             result['handler'] = handler
             handler.modify_document(doc)
             if handler.failed:
@@ -180,7 +215,7 @@ some.foo = 57
         doc = Document()
         result = {}
         def load(filename):
-            handler = DirectoryHandler(filename=filename)
+            handler = bahd.DirectoryHandler(filename=filename)
             result['handler'] = handler
             handler.modify_document(doc)
             if handler.failed:
@@ -199,7 +234,7 @@ some.foo = 57
         doc = Document()
         result = {}
         def load(filename):
-            handler = DirectoryHandler(filename=filename)
+            handler = bahd.DirectoryHandler(filename=filename)
             result['handler'] = handler
             handler.modify_document(doc)
             if handler.failed:
@@ -212,3 +247,52 @@ some.foo = 57
         assert not doc.roots
 
         assert doc.template is FILE
+
+    def test_safe_to_fork(self):
+        doc = Document()
+        result = {}
+        def load(filename):
+            handler = bahd.DirectoryHandler(filename=filename)
+            assert handler.safe_to_fork
+            result['handler'] = handler
+            handler.modify_document(doc)
+            if handler.failed:
+                raise RuntimeError(handler.error)
+            assert not handler.safe_to_fork
+
+        with_directory_contents({
+            'main.py' : "# This script does nothing",
+        }, load)
+
+    def test_missing_filename_raises(self):
+        with pytest.raises(ValueError):
+            bahd.DirectoryHandler()
+
+    def test_url_path(self):
+        doc = Document()
+        result = {}
+        def load(filename):
+            handler = bahd.DirectoryHandler(filename=filename)
+            assert handler.safe_to_fork
+            result['handler'] = handler
+            handler.modify_document(doc)
+            if handler.failed:
+                raise RuntimeError(handler.error)
+            assert not handler.safe_to_fork
+
+        with_directory_contents({
+            'main.py' : "# This script does nothing",
+        }, load)
+
+        h = result['handler']
+        assert h.url_path().startswith("/")
+        h._main_handler._runner._failed = True
+        assert h.url_path() is None
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
