@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2017, Anaconda, Inc. All rights reserved.
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
 #
 # Powered by the Bokeh Development Team.
 #
@@ -59,11 +59,18 @@ DEFAULT_SESSION_ID = "default"
 
 DEFAULT_SERVER_WEBSOCKET_URL = websocket_url_for_server_url(DEFAULT_SERVER_HTTP_URL)
 
+__all__ = (
+    'ClientSession',
+    'pull_session',
+    'push_session',
+    'show_session',
+)
+
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
 
-def pull_session(session_id=None, url='default', io_loop=None):
+def pull_session(session_id=None, url='default', io_loop=None, arguments=None):
     ''' Create a session by loading the current server-side document.
 
     ``session.document`` will be a fresh document loaded from
@@ -103,13 +110,22 @@ def pull_session(session_id=None, url='default', io_loop=None):
         io_loop (``tornado.ioloop.IOLoop``, optional) :
             The IOLoop to use for the websocket
 
+        arguments (dict[str, str], optional) :
+            A dictionary of key/values to be passed as HTTP request arguments
+            to Bokeh application code (default: None)
+
+            Note that should only be provided when pulling new sessions.
+            If ``session_id`` is not None, or a session with ``session_id``
+            already exists, these arguments will have no effect.
+
     Returns:
         ClientSession :
             A new ClientSession connected to the server
 
     '''
+
     coords = _SessionCoordinates(session_id=session_id, url=url)
-    session = ClientSession(session_id=session_id, websocket_url=websocket_url_for_server_url(coords.url), io_loop=io_loop)
+    session = ClientSession(session_id=session_id, websocket_url=websocket_url_for_server_url(coords.url), io_loop=io_loop, arguments=arguments)
     session.pull()
     return session
 
@@ -225,7 +241,7 @@ class ClientSession(object):
 
     '''
 
-    def __init__(self, session_id=None, websocket_url=DEFAULT_SERVER_WEBSOCKET_URL, io_loop=None):
+    def __init__(self, session_id=None, websocket_url=DEFAULT_SERVER_WEBSOCKET_URL, io_loop=None, arguments=None):
         ''' A connection which attaches to a particular named session on the
         server.
 
@@ -247,12 +263,20 @@ class ClientSession(object):
             io_loop (IOLoop, optional) :
                 The IOLoop to use for the websocket
 
+            arguments (dict[str, str], optional) :
+                A dictionary of key/values to be passed as HTTP request
+                arguments to Bokeh application code (default: None)
+
+                Note that should only be provided when pulling new sessions.
+                If ``session_id`` is not None, or a session with ``session_id``
+                already exists, these arguments will have no effect.
+
         '''
         self._document = None
         self._id = self._ensure_session_id(session_id)
 
         from .connection import ClientConnection
-        self._connection = ClientConnection(session=self, io_loop=io_loop, websocket_url=websocket_url)
+        self._connection = ClientConnection(session=self, io_loop=io_loop, websocket_url=websocket_url, arguments=arguments)
 
         from ..server.callbacks import _DocumentCallbackGroup
         self._callbacks = _DocumentCallbackGroup(self._connection.io_loop)
@@ -418,8 +442,6 @@ class ClientSession(object):
 
     # Internal methods --------------------------------------------------------
 
-    # Private methods ---------------------------------------------------------
-
     def _attach_document(self, document):
         self._document = document
         self._document.on_change_dispatch_to(self)
