@@ -1,18 +1,52 @@
-from __future__ import absolute_import
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+import pytest ; pytest
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Standard library imports
 import argparse
-import pytest
+from mock import patch
 import os
 import sys
 
+# External imports
+
+# Bokeh imports
+from bokeh.command.bootstrap import main
+from bokeh._testing.util.filesystem import TmpDir, WorkingDir, with_directory_contents
+
+from . import basic_scatter_script
+
+# Module under test
+import bokeh.command.subcommands.html as schtml
+
+#-----------------------------------------------------------------------------
+# Setup
+#-----------------------------------------------------------------------------
+
 is_python2 = sys.version_info[0] == 2
 
-import bokeh.command.subcommands.html as schtml
-from bokeh.command.bootstrap import main
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
 
-from . import (
-    TmpDir, WorkingDir, with_directory_contents, basic_scatter_script
-)
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
 
 def test_create():
     import argparse
@@ -84,8 +118,7 @@ def test_basic_script(capsys):
 
         assert set(["scatter.html", "scatter.py"]) == set(os.listdir(dirname))
 
-    with_directory_contents({ 'scatter.py' : basic_scatter_script },
-                            run)
+    with_directory_contents({ 'scatter.py' : basic_scatter_script }, run)
 
 def test_basic_script_with_output_after(capsys):
     def run(dirname):
@@ -97,8 +130,7 @@ def test_basic_script_with_output_after(capsys):
 
         assert set(["foo.html", "scatter.py"]) == set(os.listdir(dirname))
 
-    with_directory_contents({ 'scatter.py' : basic_scatter_script },
-                            run)
+    with_directory_contents({ 'scatter.py' : basic_scatter_script }, run)
 
 def test_basic_script_with_output_before(capsys):
     def run(dirname):
@@ -110,5 +142,27 @@ def test_basic_script_with_output_before(capsys):
 
         assert set(["foo.html", "scatter.py"]) == set(os.listdir(dirname))
 
-    with_directory_contents({ 'scatter.py' : basic_scatter_script },
-                            run)
+    with_directory_contents({ 'scatter.py' : basic_scatter_script }, run)
+
+@patch('bokeh.util.browser.view')
+def test_show(mock_view, capsys):
+    def run(dirname):
+        with WorkingDir(dirname):
+            main(["bokeh", "html", "--show", "scatter.py"])
+        out, err = capsys.readouterr()
+        assert err == ""
+        assert out == ""
+
+        assert set(["scatter.html", "scatter.py"]) == set(os.listdir(dirname))
+        assert mock_view.called
+        assert mock_view.call_args[0] == ('scatter.html',)
+
+    with_directory_contents({ 'scatter.py' : basic_scatter_script }, run)
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
