@@ -1,3 +1,10 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Provide the ``Document`` class, which is a container for Bokeh Models to
 be reflected to the client side BokehJS library.
 
@@ -14,28 +21,36 @@ figure below:
     glyphs, etc.) that can be serialized as a single collection.
 
 '''
-from __future__ import absolute_import
+
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 import logging
+log = logging.getLogger(__name__)
 
-from bokeh.util import deprecation
-
-logger = logging.getLogger(__name__)
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
 
+# Standard library imports
 from collections import defaultdict
 from json import loads
 import sys
 
+# External imports
 import jinja2
 from six import string_types
 
+# Bokeh imports
 from ..core.enums import HoldPolicy
 from ..core.json_encoder import serialize_json
 from ..core.query import find
 from ..core.templates import FILE
 from ..core.validation import check_integrity
 from ..events import Event
-from ..themes import default as default_theme
+from ..themes import default as default_theme, built_in_themes
 from ..themes import Theme
 from ..util.callback_manager import _check_callback
 from ..util.datatypes import MultiValuedDict
@@ -46,8 +61,24 @@ from .events import ModelChangedEvent, RootAddedEvent, RootRemovedEvent, Session
 from .locking import UnlockedDocumentProxy
 from .util import initialize_references_json, instantiate_references_json, references_json
 
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
+
 DEFAULT_TITLE = "Bokeh Application"
 
+__all__ = (
+    'Document',
+)
+
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
 class Document(object):
     ''' The basic unit of serialization for Bokeh.
 
@@ -70,6 +101,7 @@ class Document(object):
         self._all_models_by_name = MultiValuedDict()
         self._all_former_model_ids = set()
         self._callbacks = {}
+        self._session_destroyed_callbacks = set()
         self._session_callbacks = set()
         self._session_context = None
         self._modules = []
@@ -100,6 +132,17 @@ class Document(object):
         '''
         return list(self._session_callbacks)
 
+    @property
+    def session_destroyed_callbacks(self):
+        ''' A list of all the on_session_destroyed callbacks on this document.
+
+        '''
+        return self._session_destroyed_callbacks
+
+    @session_destroyed_callbacks.setter
+    def session_destroyed_callbacks(self, callbacks):
+        self._session_destroyed_callbacks = callbacks
+
     @property
     def session_context(self):
         ''' The ``SessionContext`` for this document.
@@ -116,8 +159,8 @@ class Document(object):
 
     @template.setter
     def template(self, template):
-        if not isinstance(template, jinja2.Template):
-            raise ValueError("Document templates must be Jinja2 Templates")
+        if not isinstance(template, (jinja2.Template, string_types)):
+            raise ValueError("document template must be Jinja2 template or a string")
         self._template = template
 
     @property
@@ -145,11 +188,23 @@ class Document(object):
     def theme(self, theme):
         if theme is None:
             theme = default_theme
-        if not isinstance(theme, Theme):
-            raise ValueError("Theme must be an instance of the Theme class")
+
         if self._theme is theme:
             return
-        self._theme = theme
+
+        if isinstance(theme, string_types):
+            try:
+                self._theme = built_in_themes[theme]
+            except KeyError:
+                raise ValueError(
+                    "{0} is not a built-in theme; available themes are "
+                    "{1}".format(theme, ', '.join(built_in_themes.keys()))
+                )
+        elif isinstance(theme, Theme):
+            self._theme = theme
+        else:
+            raise ValueError("Theme must be a string or an instance of the Theme class")
+
         for model in self._all_models.values():
             self._theme.apply_to_model(model)
 
@@ -278,7 +333,7 @@ class Document(object):
     def apply_json_event(self, json):
         event = loads(json, object_hook=Event.decode_json)
         if not isinstance(event, Event):
-            logger.warn('Could not decode event json: %s' % json)
+            log.warn('Could not decode event json: %s' % json)
         else:
             for obj in self._subscribed_models[event.event_name]:
                 obj._trigger_event(event)
@@ -331,7 +386,7 @@ class Document(object):
                     if patched_id not in self._all_former_model_ids:
                         raise RuntimeError("Cannot apply patch to %s which is not in the document" % (str(patched_id)))
                     else:
-                        logger.warn("Cannot apply patch to %s which is not in the document anymore" % (str(patched_id)))
+                        log.warn("Cannot apply patch to %s which is not in the document anymore" % (str(patched_id)))
                         break
                 patched_obj = self._all_models[patched_id]
                 attr = event_json['attr']
@@ -352,7 +407,7 @@ class Document(object):
                     raise RuntimeError("Cannot stream to %s which is not in the document" % (str(source_id)))
                 source = self._all_models[source_id]
                 data = event_json['data']
-                rollover = event_json['rollover']
+                rollover = event_json.get('rollover', None)
                 source._stream(data, rollover, setter)
 
             elif event_json['kind'] == 'ColumnsPatched':
@@ -435,7 +490,7 @@ class Document(object):
         from gc import get_referrers
         from types import FrameType
 
-        logger.debug("Deleting %s modules for %s" % (len(self._modules), self))
+        log.debug("Deleting %s modules for %s" % (len(self._modules), self))
 
         for module in self._modules:
 
@@ -455,7 +510,7 @@ class Document(object):
             referrers = [x for x in referrers if x is not self._modules]
             referrers = [x for x in referrers if not isinstance(x, FrameType)]
             if len(referrers) != 0:
-                logger.error("Module %r has extra unexpected referrers! This could indicate a serious memory leak. Extra referrers: %r" % (module, referrers))
+                log.error("Module %r has extra unexpected referrers! This could indicate a serious memory leak. Extra referrers: %r" % (module, referrers))
 
             # remove the reference from sys.modules
             if module.__name__ in sys.modules:
@@ -573,7 +628,7 @@ class Document(object):
 
         '''
         if self._hold is not None and self._hold != policy:
-            logger.warn("hold already active with '%s', ignoring '%s'" % (self._hold, policy))
+            log.warn("hold already active with '%s', ignoring '%s'" % (self._hold, policy))
             return
         if policy not in HoldPolicy:
             raise ValueError("Unknown hold policy %r" % policy)
@@ -613,6 +668,15 @@ class Document(object):
         if not receiver in self._callbacks:
             self._callbacks[receiver] = lambda event: event.dispatch(receiver)
 
+    def on_session_destroyed(self, *callbacks):
+        ''' Provide callbacks to invoke when the session serving the Document
+        is destroyed
+
+        '''
+        for callback in callbacks:
+            _check_callback(callback, ('session_context',))
+            self._session_destroyed_callbacks.add(callback)
+
     def remove_next_tick_callback(self, callback_obj):
         ''' Remove a callback added earlier with ``add_next_tick_callback``.
 
@@ -979,16 +1043,6 @@ class Document(object):
         self._all_models = recomputed
         self._all_models_by_name = recomputed_by_name
 
-    def _deprecated_remove_session_callback(self, callback, originator):
-        deprecation.deprecated((0, 12, 15),
-                               'The ability to remove a callback function using its value',
-                               'a value returned from the function that adds a callback')
-
-        cb_objs = self._callback_objs_by_callable[originator].pop(callback)
-        for cb_obj in cb_objs:
-            self._session_callbacks.remove(cb_obj)
-        return cb_objs
-
     def _remove_session_callback(self, callback_obj, originator):
         ''' Remove a callback added earlier with ``add_periodic_callback``,
         ``add_timeout_callback``, or ``add_next_tick_callback``.
@@ -1001,16 +1055,15 @@ class Document(object):
 
         '''
         try:
-            if callable(callback_obj):
-                callback_objs = self._deprecated_remove_session_callback(callback_obj, originator)
-            else:
-                callback_objs = [callback_obj]
-                self._session_callbacks.remove(callback_obj)
-                for cb_objs in self._callback_objs_by_callable[originator].values():
-                    try:
-                        cb_objs.remove(callback_obj)
-                    except KeyError:
-                        pass
+            callback_objs = [callback_obj]
+            self._session_callbacks.remove(callback_obj)
+            for cb, cb_objs in list(self._callback_objs_by_callable[originator].items()):
+                try:
+                    cb_objs.remove(callback_obj)
+                    if not cb_objs:
+                        del self._callback_objs_by_callable[originator][cb]
+                except KeyError:
+                    pass
         except KeyError:
             raise ValueError("callback already ran or was already removed, cannot be removed again")
         # emit event so the session is notified and can remove the callback
@@ -1103,3 +1156,11 @@ def _combine_document_events(new_event, old_events):
 
     # no combination was possible
     old_events.append(new_event)
+
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
