@@ -16,6 +16,7 @@ The full list of glyphs built into Bokeh is given below:
 * :class:`~bokeh.models.glyphs.ImageURL`
 * :class:`~bokeh.models.glyphs.Line`
 * :class:`~bokeh.models.glyphs.MultiLine`
+* :class:`~bokeh.models.glyphs.MultiPolygons`
 * :class:`~bokeh.models.glyphs.Oval`
 * :class:`~bokeh.models.glyphs.Patch`
 * :class:`~bokeh.models.glyphs.Patches`
@@ -513,8 +514,7 @@ class ImageURL(XYGlyph):
     # functions derived from this class
     _args = ('url', 'x', 'y', 'w', 'h', 'angle', 'global_alpha', 'dilate')
 
-    # TODO (bev) Why is this a NumberSpec??
-    url = NumberSpec(accept_datetime=False, help="""
+    url = StringSpec(default=None, help="""
     The URLs to retrieve images from.
 
     .. note::
@@ -531,7 +531,7 @@ class ImageURL(XYGlyph):
     """)
 
     w = DistanceSpec(default=None, help="""
-    The height of the plot region that the image will occupy in data space.
+    The width of the plot region that the image will occupy in data space.
 
     The default value is ``None``, in which case the image will be displayed
     at its actual image size (regardless of the units specified here).
@@ -627,6 +627,46 @@ class MultiLine(Glyph):
     The %s values for the lines.
     """)
 
+class MultiPolygons(Glyph):
+    ''' Render several MultiPolygons.
+
+    Modeled on geoJSON - the data for the ``MultiPolygons`` glyph is
+    different in that the vector of values is not a vector of scalars.
+    Rather, it is a "list of lists of lists of lists".
+    '''
+
+    __example__ = "examples/reference/models/MultiPolygons.py"
+
+    # a canonical order for positional args that can be used for any
+    # functions derived from this class
+    _args = ('xs', 'ys')
+
+    xs = NumberSpec(help="""
+    The x-coordinates for all the patches, given as a nested list.
+
+    .. note::
+        Each item in MultiPolygons represents one MultiPolygon and each
+        MultiPolygon is comprised of n Polygons. Each Polygon is made of
+        one exterior ring optionally followed by m interior rings (holes).
+    """)
+
+    ys = NumberSpec(help="""
+    The y-coordinates for all the patches, given as a "list of lists".
+
+    .. note::
+        Each item in MultiPolygons represents one MultiPolygon and each
+        MultiPolygon is comprised of n Polygons. Each Polygon is made of
+        one exterior ring optionally followed by m interior rings (holes).
+    """)
+
+    line_props = Include(LineProps, use_prefix=False, help="""
+    The %s values for the multipolygons.
+    """)
+
+    fill_props = Include(FillProps, use_prefix=False, help="""
+    The %s values for the multipolygons.
+    """)
+
 class Oval(XYGlyph):
     u''' Render ovals.
 
@@ -1097,9 +1137,10 @@ class Wedge(XYGlyph):
     """)
 
 # XXX: allow `from bokeh.models.glyphs import *`
-from .markers import (Asterisk, Circle, CircleCross, CircleX, Cross, Diamond, DiamondCross,
-                      Hex, InvertedTriangle, Marker, Square, SquareCross, SquareX, Triangle, X)
+from .markers import (Asterisk, Circle, CircleCross, CircleX, Cross, Dash,
+                      Diamond, DiamondCross, Hex, InvertedTriangle, Marker,
+                      Square, SquareCross, SquareX, Triangle, X)
 
 # Fool pyflakes
-(Asterisk, Circle, CircleCross, CircleX, Cross, Diamond, DiamondCross,
+(Asterisk, Circle, CircleCross, CircleX, Cross, Dash, Diamond, DiamondCross,
 Hex, InvertedTriangle, Marker, Square, SquareCross, SquareX, Triangle, X)
