@@ -1,6 +1,6 @@
 import numpy as np
 
-from bokeh.models import ColumnDataSource, DataRange1d, Plot, LinearAxis, Grid
+from bokeh.models import ColumnDataSource, Plot, LinearAxis, Grid
 from bokeh.models.glyphs import Step
 from bokeh.io import curdoc, show
 
@@ -10,11 +10,8 @@ y = x**2
 
 source = ColumnDataSource(dict(x=x, y1=y, y2=y+2, y3=y+4))
 
-xdr = DataRange1d()
-ydr = DataRange1d()
-
 plot = Plot(
-    title=None, x_range=xdr, y_range=ydr, plot_width=300, plot_height=300,
+    title=None, plot_width=300, plot_height=300,
     h_symmetry=False, v_symmetry=False, min_border=0, toolbar_location=None)
 
 glyph1 = Step(x="x", y="y1", line_color="#f46d43", mode="before")
